@@ -784,3 +784,26 @@ def preprocess_df_for_ols(df, independent_var_columns, target_col) -> tuple:
         raise ValueError(f"Mismatch in rows: predictors (X_encoded) have {X_encoded.shape[0]} rows, " f"but target (y) has {y.shape[0]} rows.")
 
     return X_encoded, y
+
+
+def get_combinations(z_ind: list) -> list:
+    """
+    Generates all possible combinations of two targets from a list of target indices. Order is not important.
+
+    Args:
+        z_ind (list): A list of target indices.
+
+    Returns:
+        list: A list of tuples, where each tuple contains a combination of two target indices.
+             The order of the targets within a tuple is not important, and each combination
+             appears only once.
+
+    Examples:
+        >>> from spotpython.utils.stats import get_combinations
+        >>> z_ind = [0, 1, 2, 30]
+        >>> combinations = get_combinations(z_ind)
+        >>> print(combinations)
+        [(0, 1), (0, 2), (0, 30), (1, 2), (1, 30), (2, 30)]
+    """
+    combinations = [(z_ind[i], z_ind[j]) for i in range(len(z_ind)) for j in range(i + 1, len(z_ind))]
+    return combinations
